==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/databoxedge/kotlin/inputs/MetricCounterArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.databoxedge.kotlin.inputs

import com.pulumi.azurenative.databoxedge.inputs.MetricCounterArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * The metric counter
 * @property additionalDimensions The additional dimensions to be added to metric.
 * @property dimensionFilter The dimension filter.
 * @property instance The instance from which counter should be collected.
 * @property name The counter name.
 */
public data class MetricCounterArgs(
    public val additionalDimensions: Output<List<MetricDimensionArgs>>? = null,
    public val dimensionFilter: Output<List<MetricDimensionArgs>>? = null,
    public val instance: Output<String>? = null,
    public val name: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.databoxedge.inputs.MetricCounterArgs> {
    override fun toJava(): com.pulumi.azurenative.databoxedge.inputs.MetricCounterArgs =
        com.pulumi.azurenative.databoxedge.inputs.MetricCounterArgs.builder()
            .additionalDimensions(
                additionalDimensions?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .dimensionFilter(
                dimensionFilter?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .instance(instance?.applyValue({ args0 -> args0 }))
            .name(name.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [MetricCounterArgs].
 */
@PulumiTagMarker
public class MetricCounterArgsBuilder internal constructor() {
    private var additionalDimensions: Output<List<MetricDimensionArgs>>? = null

    private var dimensionFilter: Output<List<MetricDimensionArgs>>? = null

    private var instance: Output<String>? = null

    private var name: Output<String>? = null

    /**
     * @param value The additional dimensions to be added to metric.
     */
    @JvmName("ynubpnjnhiokrfnx")
    public suspend fun additionalDimensions(`value`: Output<List<MetricDimensionArgs>>) {
        this.additionalDimensions = value
    }

    @JvmName("clnotnmyredwswxg")
    public suspend fun additionalDimensions(vararg values: Output<MetricDimensionArgs>) {
        this.additionalDimensions = Output.all(values.asList())
    }

    /**
     * @param values The additional dimensions to be added to metric.
     */
    @JvmName("clhwphyotgrlwotp")
    public suspend fun additionalDimensions(values: List<Output<MetricDimensionArgs>>) {
        this.additionalDimensions = Output.all(values)
    }

    /**
     * @param value The dimension filter.
     */
    @JvmName("shxvaajtddbqltya")
    public suspend fun dimensionFilter(`value`: Output<List<MetricDimensionArgs>>) {
        this.dimensionFilter = value
    }

    @JvmName("ixggrscrwjdwwvxp")
    public suspend fun dimensionFilter(vararg values: Output<MetricDimensionArgs>) {
        this.dimensionFilter = Output.all(values.asList())
    }

    /**
     * @param values The dimension filter.
     */
    @JvmName("mkavaxaxbdgwylxw")
    public suspend fun dimensionFilter(values: List<Output<MetricDimensionArgs>>) {
        this.dimensionFilter = Output.all(values)
    }

    /**
     * @param value The instance from which counter should be collected.
     */
    @JvmName("igscnmakfuitiwri")
    public suspend fun instance(`value`: Output<String>) {
        this.instance = value
    }

    /**
     * @param value The counter name.
     */
    @JvmName("qsohsejkpwgpxdkv")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value The additional dimensions to be added to metric.
     */
    @JvmName("qribodxqgepoedyg")
    public suspend fun additionalDimensions(`value`: List<MetricDimensionArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.additionalDimensions = mapped
    }

    /**
     * @param argument The additional dimensions to be added to metric.
     */
    @JvmName("hxowcyetmkmkgddo")
    public suspend
    fun additionalDimensions(argument: List<suspend MetricDimensionArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            MetricDimensionArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.additionalDimensions = mapped
    }

    /**
     * @param argument The additional dimensions to be added to metric.
     */
    @JvmName("iylnprmvvjytvlgl")
    public suspend fun additionalDimensions(
        vararg
        argument: suspend MetricDimensionArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            MetricDimensionArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.additionalDimensions = mapped
    }

    /**
     * @param argument The additional dimensions to be added to metric.
     */
    @JvmName("gvttweoxoyrbkyxm")
    public suspend fun additionalDimensions(argument: suspend MetricDimensionArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(MetricDimensionArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.additionalDimensions = mapped
    }

    /**
     * @param values The additional dimensions to be added to metric.
     */
    @JvmName("epxlacabutojsibm")
    public suspend fun additionalDimensions(vararg values: MetricDimensionArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.additionalDimensions = mapped
    }

    /**
     * @param value The dimension filter.
     */
    @JvmName("oieolbjnkwrtqgwj")
    public suspend fun dimensionFilter(`value`: List<MetricDimensionArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dimensionFilter = mapped
    }

    /**
     * @param argument The dimension filter.
     */
    @JvmName("fbfheyodtjjybswx")
    public suspend
    fun dimensionFilter(argument: List<suspend MetricDimensionArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            MetricDimensionArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.dimensionFilter = mapped
    }

    /**
     * @param argument The dimension filter.
     */
    @JvmName("gjecyutfpqnadjiw")
    public suspend fun dimensionFilter(
        vararg
        argument: suspend MetricDimensionArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            MetricDimensionArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.dimensionFilter = mapped
    }

    /**
     * @param argument The dimension filter.
     */
    @JvmName("yiweslssijmqajkm")
    public suspend fun dimensionFilter(argument: suspend MetricDimensionArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(MetricDimensionArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.dimensionFilter = mapped
    }

    /**
     * @param values The dimension filter.
     */
    @JvmName("ahokyfwbtpeihvfe")
    public suspend fun dimensionFilter(vararg values: MetricDimensionArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.dimensionFilter = mapped
    }

    /**
     * @param value The instance from which counter should be collected.
     */
    @JvmName("dfriiubdreeurthr")
    public suspend fun instance(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.instance = mapped
    }

    /**
     * @param value The counter name.
     */
    @JvmName("ftifawtjrrdrgtos")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    internal fun build(): MetricCounterArgs = MetricCounterArgs(
        additionalDimensions = additionalDimensions,
        dimensionFilter = dimensionFilter,
        instance = instance,
        name = name ?: throw PulumiNullFieldException("name"),
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/databoxedge/kotlin/inputs/MetricCounterArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.databoxedge.kotlin.inputs

import com.pulumi.azurenative.databoxedge.inputs.MetricCounterArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * The metric counter
 * @property additionalDimensions The additional dimensions to be added to metric.
 * @property dimensionFilter The dimension filter.
 * @property instance The instance from which counter should be collected.
 * @property name The counter name.
 */
public data class MetricCounterArgs(
    public val additionalDimensions: Output<List<MetricDimensionArgs>>? = null,
    public val dimensionFilter: Output<List<MetricDimensionArgs>>? = null,
    public val instance: Output<String>? = null,
    public val name: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.databoxedge.inputs.MetricCounterArgs> {
    override fun toJava(): com.pulumi.azurenative.databoxedge.inputs.MetricCounterArgs =
        com.pulumi.azurenative.databoxedge.inputs.MetricCounterArgs.builder()
            .additionalDimensions(
                additionalDimensions?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .dimensionFilter(
                dimensionFilter?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .instance(instance?.applyValue({ args0 -> args0 }))
            .name(name.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [MetricCounterArgs].
 */
@PulumiTagMarker
public class MetricCounterArgsBuilder internal constructor() {
    private var additionalDimensions: Output<List<MetricDimensionArgs>>? = null

    private var dimensionFilter: Output<List<MetricDimensionArgs>>? = null

    private var instance: Output<String>? = null

    private var name: Output<String>? = null

    /**
     * @param value The additional dimensions to be added to metric.
     */
    @JvmName("oaqjnphhmdwodlaw")
    public suspend fun additionalDimensions(`value`: Output<List<MetricDimensionArgs>>) {
        this.additionalDimensions = value
    }

    @JvmName("bdrgkajtknciijnc")
    public suspend fun additionalDimensions(vararg values: Output<MetricDimensionArgs>) {
        this.additionalDimensions = Output.all(values.asList())
    }

    /**
     * @param values The additional dimensions to be added to metric.
     */
    @JvmName("ivvgnscvhycamsek")
    public suspend fun additionalDimensions(values: List<Output<MetricDimensionArgs>>) {
        this.additionalDimensions = Output.all(values)
    }

    /**
     * @param value The dimension filter.
     */
    @JvmName("vrryloknutlhaoue")
    public suspend fun dimensionFilter(`value`: Output<List<MetricDimensionArgs>>) {
        this.dimensionFilter = value
    }

    @JvmName("gwepuuinbvgttsxv")
    public suspend fun dimensionFilter(vararg values: Output<MetricDimensionArgs>) {
        this.dimensionFilter = Output.all(values.asList())
    }

    /**
     * @param values The dimension filter.
     */
    @JvmName("kadjksipumgehbvl")
    public suspend fun dimensionFilter(values: List<Output<MetricDimensionArgs>>) {
        this.dimensionFilter = Output.all(values)
    }

    /**
     * @param value The instance from which counter should be collected.
     */
    @JvmName("rtfwwuayeavpfgse")
    public suspend fun instance(`value`: Output<String>) {
        this.instance = value
    }

    /**
     * @param value The counter name.
     */
    @JvmName("tdbfnswokibachnw")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value The additional dimensions to be added to metric.
     */
    @JvmName("ioliaybwsuykrbql")
    public suspend fun additionalDimensions(`value`: List<MetricDimensionArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.additionalDimensions = mapped
    }

    /**
     * @param argument The additional dimensions to be added to metric.
     */
    @JvmName("fkrpllsadvucsfjm")
    public suspend
    fun additionalDimensions(argument: List<suspend MetricDimensionArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            MetricDimensionArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.additionalDimensions = mapped
    }

    /**
     * @param argument The additional dimensions to be added to metric.
     */
    @JvmName("avqacswiftwbcrwg")
    public suspend fun additionalDimensions(
        vararg
        argument: suspend MetricDimensionArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            MetricDimensionArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.additionalDimensions = mapped
    }

    /**
     * @param argument The additional dimensions to be added to metric.
     */
    @JvmName("qsfrghuwouboxpcy")
    public suspend fun additionalDimensions(argument: suspend MetricDimensionArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(MetricDimensionArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.additionalDimensions = mapped
    }

    /**
     * @param values The additional dimensions to be added to metric.
     */
    @JvmName("xejqocojcwqsxhtv")
    public suspend fun additionalDimensions(vararg values: MetricDimensionArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.additionalDimensions = mapped
    }

    /**
     * @param value The dimension filter.
     */
    @JvmName("ltqrqtxvfpvespov")
    public suspend fun dimensionFilter(`value`: List<MetricDimensionArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dimensionFilter = mapped
    }

    /**
     * @param argument The dimension filter.
     */
    @JvmName("fkfcfhswetnaclyd")
    public suspend
    fun dimensionFilter(argument: List<suspend MetricDimensionArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            MetricDimensionArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.dimensionFilter = mapped
    }

    /**
     * @param argument The dimension filter.
     */
    @JvmName("qjecagidjdjxenwk")
    public suspend fun dimensionFilter(
        vararg
        argument: suspend MetricDimensionArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            MetricDimensionArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.dimensionFilter = mapped
    }

    /**
     * @param argument The dimension filter.
     */
    @JvmName("bcugelkyfkgtduih")
    public suspend fun dimensionFilter(argument: suspend MetricDimensionArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(MetricDimensionArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.dimensionFilter = mapped
    }

    /**
     * @param values The dimension filter.
     */
    @JvmName("orxkuluboytmbqwm")
    public suspend fun dimensionFilter(vararg values: MetricDimensionArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.dimensionFilter = mapped
    }

    /**
     * @param value The instance from which counter should be collected.
     */
    @JvmName("kfyyxwanuvwpivup")
    public suspend fun instance(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.instance = mapped
    }

    /**
     * @param value The counter name.
     */
    @JvmName("yoqvxpglkxjydgvn")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    internal fun build(): MetricCounterArgs = MetricCounterArgs(
        additionalDimensions = additionalDimensions,
        dimensionFilter = dimensionFilter,
        instance = instance,
        name = name ?: throw PulumiNullFieldException("name"),
    )
}
